[PATCH v2] find: implement -amin, -atime, -cmin, and -ctime
Ismael Luceno
ismael at iodev.co.uk
Sat Oct 2 00:52:22 UTC 2021
On 02/Oct/2021 02:49, Ismael Luceno wrote:
> On 02/Oct/2021 01:11, Bernhard Reutner-Fischer wrote:
> > On 29 September 2021 13:49:39 CEST, Ismael Luceno <ismael at iodev.co.uk> wrote:
> >
> > bloat-o-meter if all are on versus baseline?
> > Just curious.
> > thanks,
>
> text data bss dec hex filename
> 4806 0 0 4806 12c6 findutils/find.o.orig <- original
> 4782 0 0 4782 12ae findutils/find.o.merged <- merged mmin+mtime
> 4994 0 0 4994 1382 findutils/find.o.all <- all
>
> Average cost is 53 bytes, after the first function, but there's a slight
> difference, so here's the breakdown:
>
> - argument prep for common code:
> + 29 bytes for each *min
> + 32 bytes for each *time
> - cmd line parsing 16 bytes per function
> - strings
> + 6 bytes for each *time
> + 5 bytes for each *min
> - padding: 4 bytes with all functions
ah, I forgot to mention, common code is 98 bytes.
More information about the busybox
mailing list